@@ -14,6 +14,7 @@ from .publisher import Publisher
 from .routing import RoutingRule, Route
 from . import consumer
 from . import headers
+from .listener import ConnectionListener, ConsumerConnectionListener, RpcConnectionListener, ConnectionListenerAggregator
 
 logger = get_logger(__name__)
 _initialized = False
@@ -24,7 +25,9 @@ def __init__(enable_consumers: bool = True,
              prefetch_count: int = 1,
              global_prefetch: bool = False,
              rpc_prefetch_count: int = 1,
-             rpc_global_prefetch: bool = False):
+             rpc_global_prefetch: bool = False,
+             connection_listeners: List[ConnectionListener] = None,
+             utility_connection_listeners: List[ConnectionListener] = None):
     """
     Initialize queue module
     :param enable_consumers: register consumers
@@ -32,11 +35,18 @@ def __init__(enable_consumers: bool = True,
     :param global_prefetch: set prefetch limit on connection instead of channel
     :param rpc_prefetch_count: maximum unacknowledged messages per channel for rpc connection
     :param rpc_global_prefetch: set prefetch limit on connection instead of channel for rpc connection
+    :param connection_listeners: list of connection listeners and sub-classes
+    :param utility_connection_listeners: utility connection listeners
     :return:
     """
     global _initialized
     global _consumers_enabled
 
+    if connection_listeners is None:
+        connection_listeners = []
+    if utility_connection_listeners is None:
+        utility_connection_listeners = []
+
     if _initialized:
         return
 
@@ -46,7 +56,8 @@ def __init__(enable_consumers: bool = True,
 
     from .connection import connection_factory
 
-    initialization_connection: ReconnectingAMQPConnection = connection_factory.create()
+    utility_connection_listener: ConnectionListener = ConnectionListenerAggregator(utility_connection_listeners)
+    initialization_connection: ReconnectingAMQPConnection = connection_factory.create(connection_listener=utility_connection_listener)
     try:
         _declare_dead_letter_exchange(initialization_connection)
         _declare_waiting_transcription_result_exchange(initialization_connection)
@@ -55,12 +66,16 @@ def __init__(enable_consumers: bool = True,
 
     routing.__init__()
     if enable_consumers:
+        consumer_connection_listener, rpc_connection_listener = _parse_connection_listeners(connection_listeners)
+
         consumer.__init__(connection_factory,
                           prefetch_count=prefetch_count,
-                          global_prefetch=global_prefetch)
+                          global_prefetch=global_prefetch,
+                          connection_listener=consumer_connection_listener)
         rpc.__init__(connection_factory,
                      prefetch_count=rpc_prefetch_count,
-                     global_prefetch=rpc_global_prefetch)
+                     global_prefetch=rpc_global_prefetch,
+                     connection_listener=rpc_connection_listener)
 
     publisher.__init__(connection_factory)
 
@@ -68,6 +83,23 @@ def __init__(enable_consumers: bool = True,
     _consumers_enabled = True
 
 
+def _parse_connection_listeners(connection_listeners: List[ConnectionListener]) -> Tuple[ConnectionListenerAggregator, ConnectionListenerAggregator]:
+    consumer_connection_listeners: List[ConnectionListener] = []
+    rpc_connection_listeners: List[ConnectionListener] = []
+
+    for listener in connection_listeners:
+        if isinstance(listener, ConsumerConnectionListener):
+            consumer_connection_listeners.append(listener)
+        elif isinstance(listener, RpcConnectionListener):
+            rpc_connection_listeners.append(listener)
+        else:
+            consumer_connection_listeners.append(listener)
+            rpc_connection_listeners.append(listener)
+
+    return ConnectionListenerAggregator(connection_listeners=consumer_connection_listeners, component=Component.CONSUMER), \
+           ConnectionListenerAggregator(connection_listeners=rpc_connection_listeners, component=Component.RPC)
+
+
 def _declare_dead_letter_exchange(connection: ReconnectingAMQPConnection):
     with connection.channel() as channel:
         channel.exchange_declare(exchange=DEAD_LETTER_EXCHANGE_NAME,
@@ -185,10 +217,14 @@ def rpc_call(route: Route,
 def healthy() -> Tuple[bool, Dict[str, str]]:
     consumer_state: ConnectionState = consumer.get_connection_state()
     publisher_state: ConnectionState = publisher.get_connection_state()
+    rpc_state: ConnectionState = rpc.get_connection_state()
 
-    queue_healthy: bool = consumer_state == ConnectionState.CONNECTED and publisher_state == ConnectionState.CONNECTED
+    queue_healthy: bool = consumer_state == ConnectionState.CONNECTED \
+                          and publisher_state == ConnectionState.CONNECTED \
+                          and rpc_state == ConnectionState.CONNECTED
 
     return queue_healthy, {
-        'CONSUMER': consumer_state.value,
-        'PUBLISHER': publisher_state.value
+        Component.CONSUMER.value: consumer_state.value,
+        Component.PUBLISHER.value: publisher_state.value,
+        Component.RPC.value: rpc_state.value
     }
