@@ -11,6 +11,7 @@ from vatis.asr_commons.config.logging import get_logger
 
 from . import environment
 from .exceptions import ConnectionClosedException, RetriesExceededException
+from .listener import ConnectionListener
 
 
 logger = get_logger(__name__)
@@ -24,6 +25,29 @@ class ConnectionState(Enum):
     NOT_CREATED = 'NOT_CREATED'
 
 
+class SafeConnectionListener(ConnectionListener):
+    def __init__(self, connection_listener: ConnectionListener):
+        self._connection: connection_listener = connection_listener
+
+    def safe_on_connection_permanently_lost(self):
+        try:
+            self._connection.on_connection_permanently_lost(None)
+        except Exception:
+            pass
+
+    def safe_on_connection_lost(self):
+        try:
+            self._connection.on_connection_lost(None)
+        except Exception:
+            pass
+
+    def safe_on_connect(self):
+        try:
+            self._connection.on_connect(None)
+        except Exception:
+            pass
+
+
 class ReconnectingAMQPConnection:
     CONNECTION_COUNTER = 0
 
@@ -33,8 +57,8 @@ class ReconnectingAMQPConnection:
                  password: str = ConnectionParameters.DEFAULT_PASSWORD,
                  reconnection_delay: float = 3,
                  reconnection_retries: int = 50,
-                 name: Optional[str] = None
-                 ):
+                 name: Optional[str] = None,
+                 connection_listener: Optional[ConnectionListener] = None):
         """
         :param host: rabbitmq host
         :param port: rabbitmq port
@@ -42,6 +66,8 @@ class ReconnectingAMQPConnection:
         :param password: rabbitmq pass
         :param reconnection_delay: delay in seconds between reconnection attempts
         :param reconnection_retries: maximum retries before declaring the connection lost
+        :param name: connection name
+        :param connection_listener: connection listener
         """
         self._connection_parameters: ConnectionParameters = pika.ConnectionParameters(
             host=host,
@@ -57,6 +83,7 @@ class ReconnectingAMQPConnection:
         self._state: ConnectionState = ConnectionState.CONNECTING
         self._name: str = name if name is not None else f'connection-{str(ReconnectingAMQPConnection.CONNECTION_COUNTER)}'
         ReconnectingAMQPConnection.CONNECTION_COUNTER += 1
+        self._connection_listener: SafeConnectionListener = SafeConnectionListener(connection_listener)
 
         self._reestablish_connection_if_dropped()
 
@@ -81,15 +108,20 @@ class ReconnectingAMQPConnection:
                         self._connection = pika.BlockingConnection(self._connection_parameters)
                         self._connection.process_data_events()
                     except Exception as e:
+                        if retries == 1:
+                            self._connection_listener.safe_on_connection_lost()
+
                         logger.exception(f'{self._name}: Retry {retries} of {self._reconnection_retries}. Exception {str(e)}')
                         retries += 1
                         time.sleep(self._reconnection_delay)
 
                 if self._connection_closed():
                     self.close()
+                    self._connection_listener.safe_on_connection_permanently_lost()
                     raise RetriesExceededException()
 
                 self._state = ConnectionState.CONNECTED
+                self._connection_listener.safe_on_connect()
 
     def _connection_closed(self) -> bool:
         return self._connection is None or not self._connection.is_open or self._connection.is_closed
@@ -140,7 +172,7 @@ class ConnectionFactory:
     def __post_init__(self):
         self._connections = []
 
-    def create(self) -> ReconnectingAMQPConnection:
+    def create(self, connection_listener: Optional[ConnectionListener] = None) -> ReconnectingAMQPConnection:
         if self._closed:
             raise ConnectionClosedException()
 
@@ -148,7 +180,8 @@ class ConnectionFactory:
             host=self.host,
             port=self.port,
             user=self.user,
-            password=self.password
+            password=self.password,
+            connection_listener=connection_listener
         )
 
         self._connections.append(connection)
