@@ -1,3 +1,5 @@
+from enum import Enum
+
 from pika.exchange_type import ExchangeType
 
 DEFAULT_EXCHANGE_NAME: str = ''
@@ -15,3 +17,9 @@ SPEAKER_DIARIZATION_REQUESTS_QUEUE_NAME: str = 'SPEAKER_DIARIZATION_REQUESTS'
 # Delivery modes
 DELIVERY_MODE_TRANSIENT: int = 1
 DELIVERY_MODE_PERSISTENT: int = 2
+
+
+class Component(Enum):
+    CONSUMER = 'CONSUMER'
+    PUBLISHER = 'PUBLISHER'
+    RPC = 'RPC'
