@@ -17,6 +17,7 @@ from .exceptions import RetriesExceededException, ConnectionClosedException, NoC
     CorruptedBodyException, UnknownBodyTypeException
 from .model import Queue, Exchange, DEFAULT_EXCHANGE, Message
 from .headers import *
+from .listener import ConnectionListener
 
 from typeguard import check_type
 
@@ -109,7 +110,7 @@ class ConsumerLoop:
         self._execution_delay: float = execution_delay
         self._prefect_count: int = prefetch_count
         self._global_prefetch: bool = global_prefetch
-        self._loop: Thread = Thread(name='consumer-loop', target=ConsumerLoop._consumer_loop, args=[self], daemon=True)
+        self._loop: Thread = Thread(name='amqp-consumer-loop', target=ConsumerLoop._consumer_loop, args=[self], daemon=True)
         self._add_listener_condition: Condition = Condition()
         self._thread_pool: ThreadPoolExecutor = ThreadPoolExecutor(max_workers=prefetch_count,
                                                                    thread_name_prefix='queue-message-dispatcher-')
@@ -141,7 +142,9 @@ class ConsumerLoop:
                                                         auto_ack=False)
 
                         logger.info('Added listeners. Channel prepared')
-
+                    except RetriesExceededException:
+                        logger.error('Connection can\'t be established')
+                        break
                     except Exception as e:
                         logger.exception(f'Retry {retries} of {self._reconnection_retries}. Exception {str(e)}')
                         retries += 1
@@ -329,7 +332,8 @@ class ConsumerLoop:
 class ConsumerManager(MessageListener):
     def __init__(self, connection_factory: ConnectionFactory,
                  prefetch_count: int = 1,
-                 global_prefetch: bool = False):
+                 global_prefetch: bool = False,
+                 connection_listener: Optional[ConnectionListener] = None):
         """
         Manager of consumers of a queue.
         It creates a channel for each new consumer that can be configured by the attributes in the Consumer
@@ -342,7 +346,7 @@ class ConsumerManager(MessageListener):
         self._connection_factory: ConnectionFactory = connection_factory
         self._lock: RLock = RLock()
         self._consumer_loop: ConsumerLoop = \
-            ConsumerLoop(self._connection_factory.create(),
+            ConsumerLoop(self._connection_factory.create(connection_listener=connection_listener),
                          prefetch_count=prefetch_count,
                          global_prefetch=global_prefetch)
         self._queue_consumers: Dict[str, List[Consumer]] = {}
@@ -427,12 +431,14 @@ consumer_manager: Optional[ConsumerManager]
 
 def __init__(connection_factory: ConnectionFactory,
              prefetch_count: int = 1,
-             global_prefetch: bool = False):
+             global_prefetch: bool = False,
+             connection_listener: Optional[ConnectionListener] = None):
     global consumer_manager
 
     consumer_manager = ConsumerManager(connection_factory,
                                        prefetch_count=prefetch_count,
-                                       global_prefetch=global_prefetch)
+                                       global_prefetch=global_prefetch,
+                                       connection_listener=connection_listener)
 
 
 def close():
